#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.component.theme.interfaces import \
    ITagsManagerTarget, ITagsManager, \
    IThemesManagerTarget, IThemesManager, \
    ICollectionsManagerTarget, ICollectionsManager
from pyams_content.interfaces import MANAGE_TOOL_PERMISSION, MANAGE_SITE_ROOT_PERMISSION
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces.data import IObjectData
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

# import packages
from pyams_content.skin import pyams_content
from pyams_form.form import ajax_config
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem, MenuDivider
from pyams_utils.fanstatic import get_resource_path
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from z3c.form import field
from zope.interface import alsoProvides

from pyams_content import _


#
# Tags management view
#

@viewlet_config(name='tags.divider', context=ITagsManagerTarget, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SITE_ROOT_PERMISSION, weight=39)
class TagsManagerMenuDivider(MenuDivider):
    """Tags manager menu divider"""


@viewlet_config(name='tags-manager.menu', context=ITagsManagerTarget, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_SITE_ROOT_PERMISSION, weight=40)
class TagsManagerMenu(MenuItem):
    """Tags menu"""

    label = _("Tags settings...")
    icon_class = 'fa-tag'
    url = 'tags.html'
    modal_target = True


@pagelet_config(name='tags.html', context=ITagsManagerTarget, layer=IPyAMSLayer,
                permission=MANAGE_TOOL_PERMISSION)
@ajax_config(name='tags.json', context=ITagsManagerTarget, layer=IPyAMSLayer)
class TagsManagerEditForm(AdminDialogEditForm):
    """Tags manager edit form"""

    prefix = 'manager_themes.'

    legend = _("Selected tags")

    fields = field.Fields(ITagsManager)
    edit_permission = MANAGE_SITE_ROOT_PERMISSION

    def getContent(self):
        return ITagsManager(self.context)

    def updateWidgets(self, prefix=None):
        super(TagsManagerEditForm, self).updateWidgets(prefix)
        widget = self.widgets['thesaurus_name']
        widget.object_data = {
            'ams-plugins': 'pyams_content',
            'ams-plugin-pyams_content-src': get_resource_path(pyams_content),
            'ams-plugin-pyams_content-callback': 'PyAMS_content.themes.initExtracts',
            'ams-plugin-pyams_content-async': 'false'
        }
        alsoProvides(widget, IObjectData)
        widget = self.widgets['extract_name']
        widget.object_data = {
            'ams-events-handlers': {
                'select2-open': 'PyAMS_content.themes.getExtracts'
            }
        }
        alsoProvides(widget, IObjectData)


#
# Themes management view
#

@viewlet_config(name='themes-manager.menu', context=IThemesManagerTarget, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_TOOL_PERMISSION, weight=41)
class ThemesManagerMenu(MenuItem):
    """Themes menu"""

    label = _("Themes settings...")
    icon_class = 'fa-tags'
    url = 'themes.html'
    modal_target = True


@pagelet_config(name='themes.html', context=IThemesManagerTarget, layer=IPyAMSLayer,
                permission=MANAGE_TOOL_PERMISSION)
@ajax_config(name='themes.json', context=IThemesManagerTarget, layer=IPyAMSLayer)
class ThemesManagerEditForm(AdminDialogEditForm):
    """Themes manager edit form"""

    prefix = 'manager_themes.'

    legend = _("Selected themes")

    fields = field.Fields(IThemesManager)
    edit_permission = MANAGE_TOOL_PERMISSION

    def getContent(self):
        return IThemesManager(self.context)

    def updateWidgets(self, prefix=None):
        super(ThemesManagerEditForm, self).updateWidgets(prefix)
        widget = self.widgets['thesaurus_name']
        widget.object_data = {
            'ams-plugins': 'pyams_content',
            'ams-plugin-pyams_content-src': get_resource_path(pyams_content),
            'ams-plugin-pyams_content-callback': 'PyAMS_content.themes.initExtracts',
            'ams-plugin-pyams_content-async': 'false'
        }
        alsoProvides(widget, IObjectData)
        widget = self.widgets['extract_name']
        widget.object_data = {
            'ams-events-handlers': {
                'select2-open': 'PyAMS_content.themes.getExtracts'
            }
        }
        alsoProvides(widget, IObjectData)


#
# Collections management view
#

@viewlet_config(name='collections-manager.menu', context=ICollectionsManagerTarget, layer=IAdminLayer,
                manager=IPropertiesMenu, permission=MANAGE_TOOL_PERMISSION, weight=42)
class CollectionsManagerMenu(MenuItem):
    """Collections menu"""

    label = _("Collections settings...")
    icon_class = 'fa-book'
    url = 'collections.html'
    modal_target = True


@pagelet_config(name='collections.html', context=ICollectionsManagerTarget, layer=IPyAMSLayer,
                permission=MANAGE_TOOL_PERMISSION)
@ajax_config(name='collections.json', context=ICollectionsManagerTarget, layer=IPyAMSLayer)
class CollectionsManagerEditForm(AdminDialogEditForm):
    """Collections manager edit form"""

    prefix = 'manager_themes.'

    legend = _("Selected collections")

    fields = field.Fields(ICollectionsManager)
    edit_permission = MANAGE_TOOL_PERMISSION

    def getContent(self):
        return ICollectionsManager(self.context)

    def updateWidgets(self, prefix=None):
        super(CollectionsManagerEditForm, self).updateWidgets(prefix)
        widget = self.widgets['thesaurus_name']
        widget.object_data = {
            'ams-plugins': 'pyams_content',
            'ams-plugin-pyams_content-src': get_resource_path(pyams_content),
            'ams-plugin-pyams_content-callback': 'PyAMS_content.collections.initExtracts',
            'ams-plugin-pyams_content-async': 'false'
        }
        alsoProvides(widget, IObjectData)
        widget = self.widgets['extract_name']
        widget.object_data = {
            'ams-events-handlers': {
                'select2-open': 'PyAMS_content.themes.getExtracts'
            }
        }
        alsoProvides(widget, IObjectData)
