#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_content.features.menu.interfaces import IMenu, IMenusContainer, IMenuLink

# import packages
from pyams_content.component.association.container import AssociationContainer
from pyams_sequence.reference import get_reference_target
from pyams_utils.zodb import volatile_property
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


#
# Menus classes
#

@implementer(IMenu)
class Menu(AssociationContainer):
    """Associations menu"""

    visible = FieldProperty(IMenu['visible'])
    title = FieldProperty(IMenu['title'])
    reference = FieldProperty(IMenu['reference'])

    @volatile_property
    def target(self):
        return get_reference_target(self.reference)

    def get_target(self, state=None):
        if not state:
            return self.target
        else:
            return get_reference_target(self.reference)


@implementer(IMenusContainer)
class MenusContainer(AssociationContainer):
    """Associations menus container"""

    def get_visible_items(self, request=None):
        yield from filter(lambda x: IMenu(x).visible, self.values())
